/**
 * @generated
 */
public class Example
{
  /**
   * @generated
   */
  public void method1()
  { 
  }  

  /**
   * @generated
   */
  public String method2(float t1, String t2, int t3)
  {
    return Float.toString(t1) + t2;
  }  

  /**
   * @generated
   */
  public void method3(float t1)
  {
  }  

  public String method4(float t1, float t2)
  {
    return Float.toString(t1);
  }

  public void methodTarget()
  {
  }
}
