/*
 * generated by Xtext
 */
package org.eclipse.emf.ecore.xcore.parser.antlr;

import com.google.inject.Inject;
import org.eclipse.emf.ecore.xcore.parser.antlr.internal.InternalXcoreParser;
import org.eclipse.emf.ecore.xcore.services.XcoreGrammarAccess;
import org.eclipse.xtext.parser.antlr.AbstractAntlrParser;
import org.eclipse.xtext.parser.antlr.XtextTokenStream;

public class XcoreParser extends AbstractAntlrParser {

	@Inject
	private XcoreGrammarAccess grammarAccess;

	@Override
	protected void setInitialHiddenTokens(XtextTokenStream tokenStream) {
		tokenStream.setInitialHiddenTokens("RULE_WS", "RULE_ML_COMMENT", "RULE_SL_COMMENT");
	}
	

	@Override
	protected InternalXcoreParser createParser(XtextTokenStream stream) {
		return new InternalXcoreParser(stream, getGrammarAccess());
	}

	@Override 
	protected String getDefaultRuleName() {
		return "XPackage";
	}

	public XcoreGrammarAccess getGrammarAccess() {
		return this.grammarAccess;
	}

	public void setGrammarAccess(XcoreGrammarAccess grammarAccess) {
		this.grammarAccess = grammarAccess;
	}
}
