/**
 */
package org.eclipse.example.library;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import org.eclipse.emf.common.util.Enumerator;

/**
 * <!-- begin-user-doc -->
 * A representation of the literals of the enumeration '<em><b>Book Category</b></em>',
 * and utility methods for working with them.
 * <!-- end-user-doc -->
 * @see org.eclipse.example.library.LibraryPackage#getBookCategory()
 * @model
 * @generated
 */
public enum BookCategory implements Enumerator
{
  /**
   * The '<em><b>Mystery2</b></em>' literal object.
   * target comment
   * <!-- begin-user-doc -->
   * target comment Mystery2
   * <!-- end-user-doc -->
   * @see #MYSTERY
   * @generated NOT
   * @ordered
   */
  MYSTERY2_LITERAL(0, "Target Mystery2", "Mystery") //$NON-NLS-1$ //$NON-NLS-2$ // Mystery2 
  ,
  /**
   * The '<em><b>Science Fiction</b></em>' literal object.
   * target comment
   * <!-- begin-user-doc -->
   * target comment ScienceFiction
   * <!-- end-user-doc -->
   * @see #SCIENCE_FICTION
   * @generated NOT
   * @ordered
   */
  SCIENCE_FICTION_LITERAL(1, "Target ScienceFiction", "ScienceFiction") //$NON-NLS-1$ //$NON-NLS-2$ //ScienceFiction 
  ;
}
