/**
 * Copyright (c) 2020 Eclipse contributors and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 */
package org.eclipse.emf.ecore.xcore.ide;


/**
 * Use this class to register ide components.
 */
public class XcoreIdeModule extends AbstractXcoreIdeModule {
}
