/*
 * generated by Xtext
 */
package org.eclipse.emf.ecore.xcore.scoping;

import org.eclipse.xtext.xbase.scoping.batch.XbaseBatchScopeProvider;

public abstract class AbstractXcoreScopeProvider extends XbaseBatchScopeProvider {
}
