/*
 * generated by Xtext
 */
package org.eclipse.emf.ecore.xcore.ui.editor;

import org.eclipse.xtext.xbase.ui.editor.XbaseEditor;

/**
 * This class was generated. Customizations should only happen in a newly
 * introduced subclass.
 */
public class XcoreEditor extends XbaseEditor {
}
